@@ -6,7 +6,6 @@
 use std::process::exit;
 
 use chrono::{DateTime, offset::Utc};
-use clap;
 use anyhow::Context;
 
 use sequoia_openpgp as openpgp;
@@ -98,7 +97,7 @@ impl<'a> VerificationHelper for VHelper<'a> {
         let (certs, errs) = certs.into_iter().fold(
             (Vec::with_capacity(count), Vec::new()),
             |(mut certs, mut errs), a| {
-                if certs.len() == 0 {
+                if certs.is_empty() {
                     certs.push(a);
                 } else if certs[certs.len() - 1].fingerprint() == a.fingerprint() {
                     // Merge `a` into the last element.
@@ -113,7 +112,7 @@ impl<'a> VerificationHelper for VHelper<'a> {
                 (certs, errs)
             });
 
-        if errs.len() > 0 {
+        if !errs.is_empty() {
             eprintln!("Error merging duplicate keys:");
             for err in errs.iter() {
                 eprintln!("  {}", err);
@@ -274,7 +273,7 @@ fn main() -> Result<()> {
                  .into())
         } else {
             None
-        }.unwrap_or_else(|| std::time::SystemTime::now());
+        }.unwrap_or_else(std::time::SystemTime::now);
 
     let keyrings = matches.values_of_os("keyring")
         .expect("No keyring specified.");
